@@ -12,6 +12,6 @@ class AutoMapperDataTypeColumnWrapper(AutoMapperTextLikeBase):
         self.value: Column = value
 
     def get_column_spec(
-        self, source_df: DataFrame, current_column: Optional[Column]
+        self, source_df: Optional[DataFrame], current_column: Optional[Column]
     ) -> Column:
         return self.value
