@@ -18,7 +18,7 @@ class AutoMapperDataTypeComplex(AutoMapperDataTypeComplexBase):
         }
 
     def get_column_spec(
-        self, source_df: DataFrame, current_column: Optional[Column]
+        self, source_df: Optional[DataFrame], current_column: Optional[Column]
     ) -> Column:
         return struct(
             [
