@@ -20,9 +20,9 @@ class AutoMapperDateDataType(AutoMapperDataTypeBase):
             else AutoMapperValueParser.parse_value(value)
 
     def get_column_spec(
-        self, source_df: DataFrame, current_column: Optional[Column]
+        self, source_df: Optional[DataFrame], current_column: Optional[Column]
     ) -> Column:
-        if isinstance(self.value, AutoMapperDataTypeColumn) \
+        if source_df is not None and isinstance(self.value, AutoMapperDataTypeColumn) \
                 and not dict(source_df.dtypes)[self.value.value] == "date":
             return coalesce(
                 to_date(
