@@ -12,7 +12,7 @@ class AutoMapperDataTypeExpression(AutoMapperArrayLikeBase):
         self.value: str = value
 
     def get_column_spec(
-        self, source_df: DataFrame, current_column: Optional[Column]
+        self, source_df: Optional[DataFrame], current_column: Optional[Column]
     ) -> Column:
         if isinstance(
             self.value, str
