@@ -26,7 +26,7 @@ class AutoMapperFilterDataType(AutoMapperArrayLikeBase):
         )
 
     def get_column_spec(
-        self, source_df: DataFrame, current_column: Optional[Column]
+        self, source_df: Optional[DataFrame], current_column: Optional[Column]
     ) -> Column:
         return filter(
             self.column.get_column_spec(
