@@ -22,7 +22,7 @@ class AutoMapperRegExReplaceDataType(AutoMapperTextLikeBase):
         self.replacement: str = replacement
 
     def get_column_spec(
-        self, source_df: DataFrame, current_column: Optional[Column]
+        self, source_df: Optional[DataFrame], current_column: Optional[Column]
     ) -> Column:
         column_spec = regexp_replace(
             self.column.get_column_spec(
