@@ -21,7 +21,7 @@ class AutoMapperSubstringDataType(AutoMapperTextLikeBase):
         self.length: int = length
 
     def get_column_spec(
-        self, source_df: DataFrame, current_column: Optional[Column]
+        self, source_df: Optional[DataFrame], current_column: Optional[Column]
     ) -> Column:
         column_spec = substring(
             self.column.get_column_spec(
