@@ -6,8 +6,7 @@ from spark_auto_mapper.data_types.list import AutoMapperList
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 
-def test_auto_mapper_full(spark_session_per_function: SparkSession) -> None:
-    spark_session: SparkSession = spark_session_per_function
+def test_auto_mapper_full(spark_session: SparkSession) -> None:
     # Arrange
     spark_session.createDataFrame(
         [
